import { css } from '@emotion/css';

import { GrafanaTheme2 } from '@grafana/data';
import { featureEnabled, reportInteraction } from '@grafana/runtime';
import { SceneComponentProps, SceneObjectBase } from '@grafana/scenes';
import { LinkButton, useStyles2 } from '@grafana/ui';
import { highlightTrial } from 'app/features/admin/utils';
import { SceneShareTabState, ShareView } from 'app/features/dashboard-scene/sharing/types';
import { getDashboardSceneFor } from 'app/features/dashboard-scene/utils/utils';

import { getNewReportUrl } from '../utils/url';

import { HighlightTrialReport } from './HighlightTrialReport';
import { UpgradeReport } from './UpgradeReport';

export class ShareReport extends SceneObjectBase<SceneShareTabState> implements ShareView {
  static Component = ShareReportRenderer;

  public getTabLabel() {
    return 'Schedule report';
  }
}

function onClickCreateReport() {
  reportInteraction('dashboards_sharing_report_create_clicked');
}

function ShareReportRenderer({ model }: SceneComponentProps<ShareReport>) {
  const styles = useStyles2(getStyles);
  const isReportsCreationDisabled = !featureEnabled('reports.creation');
  const dashboard = getDashboardSceneFor(model);

  if (isReportsCreationDisabled) {
    return <UpgradeReport />;
  }

  return (
    <>
      {highlightTrial() && <HighlightTrialReport />}
      <LinkButton href={getNewReportUrl(dashboard)} onClick={onClickCreateReport} className={styles.button}>
        Create report using this dashboard
      </LinkButton>
    </>
  );
}

const getStyles = (theme: GrafanaTheme2) => {
  return {
    button: css({
      marginRight: theme.spacing(2),
    }),
  };
};
